tlslite.integration.httptlsconnection.HTTPTLSConnection

Package tlslite :: Package integration :: Module httptlsconnection :: Class HTTPTLSConnection |
[hide private]
[frames] | no frames]

# Class HTTPTLSConnection

source code

       httplib.HTTPConnection --+
                                |
    clienthelper.ClientHelper --+
                                |
                               HTTPTLSConnection

This class extends `httplib.HTTPConnection` to support TLS.

Nested Classes | [hide private]
Inherited from `httplib.HTTPConnection`: `response_class`

Instance Methods | [hide private]
__init__(self, host, port=None, strict=None, timeout=<object object at 0x1002ae0e0>, source_address=None, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None, ignoreAbruptClose=False, anon=False) Create a new HTTPTLSConnection. | source code
connect(self) Connect to the host and port specified in __init__. | source code
Inherited from `httplib.HTTPConnection`: `close`, `endheaders`, `getresponse`, `putheader`, `putrequest`, `request`, `send`, `set_debuglevel`, `set_tunnel` Inherited from `httplib.HTTPConnection` (private): `_output`, `_send_output`, `_send_request`, `_set_content_length`, `_set_hostport`, `_tunnel` Inherited from `clienthelper.ClientHelper` (private): `_handshake`

Class Variables | [hide private]
Inherited from `httplib.HTTPConnection`: `auto_open`, `debuglevel`, `default_port`, `strict` Inherited from `httplib.HTTPConnection` (private): `_http_vsn`, `_http_vsn_str`

Method Details | [hide private]

### __init__(self, host, port=None, strict=None, timeout=<object object at 0x1002ae0e0>, source_address=None, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None, ignoreAbruptClose=False, anon=False) (Constructor) | source code
Create a new HTTPTLSConnection. For client authentication, use one of these argument combinations: username, password (SRP) certChain, privateKey (certificate) For server authentication, you can either rely on the implicit mutual authentication performed by SRP or you can do certificate-based server authentication with one of these argument combinations: x509Fingerprint Certificate-based server authentication is compatible with SRP or certificate-based client authentication. The constructor does not perform the TLS handshake itself, but simply stores these arguments for later. The handshake is performed only when this class needs to connect with the server. Thus you should be prepared to handle TLS-specific exceptions when calling methods inherited from `httplib.HTTPConnection` such as request(), connect(), and send(). See the client handshake functions in tlslite.TLSConnection.TLSConnection for details on which exceptions might be raised. Parameters: `host` (str) - Server to connect to. `port` (int) - Port to connect to. `username` (str) - SRP username. Requires the 'password' argument. `password` (str) - SRP password for mutual authentication. Requires the 'username' argument. `certChain` (tlslite.x509certchain.X509CertChain or) - Certificate chain for client authentication. Requires the 'privateKey' argument. Excludes the SRP arguments. `privateKey` (tlslite.utils.rsakey.RSAKey) - Private key for client authentication. Requires the 'certChain' argument. Excludes the SRP arguments. `checker` (tlslite.checker.Checker) - Callable object called after handshaking to evaluate the connection and raise an Exception if necessary. `settings` (tlslite.handshakesettings.HandshakeSettings) - Various settings which can be used to control the ciphersuites, certificate types, and SSL/TLS versions offered by the client. `ignoreAbruptClose` (bool) - ignore the TLSAbruptCloseError on unexpected hangup. Overrides: clienthelper.ClientHelper.__init__

### connect(self) | source code
Connect to the host and port specified in __init__. Overrides: httplib.HTTPConnection.connect (inherited documentation)